==> projen-0.46.3.tar.gz: package/lib/javascript/render-options.d.ts <==
import * as inventory from '../inventory';
import { InitProjectOptionHints } from '../option-hints';
/**
 * Options for `renderProjectOptions`.
 */
export interface RenderProjectOptions {
    /**
     * The project type to render.
     */
    readonly type: inventory.ProjectType;
    /**
     * Project arguments as passed to `projen new`.
     */
    readonly args: Record<string, any>;
    /**
     * Include commented out options.
     * @default InitProjectOptionHints.FEATURED
     */
    readonly comments?: InitProjectOptionHints;
    /**
     * Inject a `__new__` attribute to the project constructor with a stringified
     * version of the project parameters and a `jsiiFqn` attribute that includes
     * the FQN of the project type. This is needed in order to generate initial
     * projenrc files.
     *
     * @default false
     */
    readonly bootstrap?: boolean;
    /**
     * A list of fields to omit from the initial projenrc file.
     * @default - none
     */
    readonly omitFromBootstrap?: string[];
}
/**
 * Renders options as if the project was created via `projen new` (embeds the __new__ field).
 */
export declare function renderProjenInitOptions(fqn: string, args: Record<string, any>, comments?: InitProjectOptionHints): any;
export declare function resolveInitProject(opts: any): {
    args: Record<string, any>;
    fqn: string;
    type: inventory.ProjectType;
    comments: InitProjectOptionHints;
} | undefined;
/**
 * Prints all parameters that can be used in a project type, alongside their descriptions.
 *
 * Parameters in `params` that aren't undefined are rendered as defaults,
 * while all other parameters are rendered as commented out.
 *
 * Returns the printed output and a set of required imports as an object
 * in the form { options, imports }.
 */
export declare function renderJavaScriptOptions(opts: RenderProjectOptions): {
    renderedOptions: string;
    imports: Set<unknown>;
};

==> projen-0.65.85.tar.gz: package/lib/javascript/render-options.d.ts <==
import * as inventory from "../inventory";
import { InitProjectOptionHints } from "../option-hints";
/**
 * Options for `renderProjectOptions`.
 */
export interface RenderProjectOptions {
    /**
     * The project type to render.
     */
    readonly type: inventory.ProjectType;
    /**
     * Project arguments as passed to `projen new`.
     */
    readonly args: Record<string, any>;
    /**
     * Include commented out options.
     * @default InitProjectOptionHints.FEATURED
     */
    readonly comments?: InitProjectOptionHints;
    /**
     * Inject a `__new__` attribute to the project constructor with a stringified
     * version of the project parameters and a `jsiiFqn` attribute that includes
     * the FQN of the project type. This is needed in order to generate initial
     * projenrc files.
     *
     * @default false
     */
    readonly bootstrap?: boolean;
    /**
     * A list of fields to omit from the initial projenrc file.
     * @default - none
     */
    readonly omitFromBootstrap?: string[];
}
/**
 * Renders options as if the project was created via `projen new` (embeds the __new__ field).
 */
export declare function renderProjenInitOptions(fqn: string, args: Record<string, any>, comments?: InitProjectOptionHints): any;
export declare function resolveInitProject(opts: any): {
    args: Record<string, any>;
    fqn: string;
    type: inventory.ProjectType;
    comments: InitProjectOptionHints;
} | undefined;
/**
 * Prints all parameters that can be used in a project type, alongside their descriptions.
 *
 * Parameters in `params` that aren't undefined are rendered as defaults,
 * while all other parameters are rendered as commented out.
 *
 * Returns the printed output and a set of required imports as an object
 * in the form { options, imports }.
 */
export declare function renderJavaScriptOptions(opts: RenderProjectOptions): {
    renderedOptions: string;
    imports: Set<unknown>;
};
